Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(63)

Unified Diff: media/base/android/media_source_player.cc

Issue 753213003: Adding a new enum "MEDIA_CODEC_ABORT" for aborted cases (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed comments Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/android/media_decoder_job.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/android/media_source_player.cc
diff --git a/media/base/android/media_source_player.cc b/media/base/android/media_source_player.cc
index 2be0d8b23471441f19d157987d0b09aa6f072c1f..6200e1ca6be18eda041ed3302c72765352d13b95 100644
--- a/media/base/android/media_source_player.cc
+++ b/media/base/android/media_source_player.cc
@@ -522,10 +522,10 @@ void MediaSourcePlayer::MediaDecoderCallback(
// and video in one file. If we separate them, we should be able to remove a
// lot of duplication.
// If the status is MEDIA_CODEC_STOPPED, stop decoding new data. The player is
// in the middle of a seek or stop event and needs to wait for the IPCs to
// come.
- if (status == MEDIA_CODEC_STOPPED)
+ if (status == MEDIA_CODEC_ABORT)
return;
if (prerolling_ && IsPrerollFinished(is_audio)) {
« no previous file with comments | « media/base/android/media_decoder_job.cc ('k') | no next file » | no next file with comments »
@@ -522,10 +522,10 @@ void MediaSourcePlayer::MediaDecoderCallback(
// and video in one file. If we separate them, we should be able to remove a
// lot of duplication.
- // If the status is MEDIA_CODEC_STOPPED, stop decoding new data. The player is
+ // If the status is MEDIA_CODEC_ABORT, stop decoding new data. The player is
// in the middle of a seek or stop event and needs to wait for the IPCs to
// come.

Powered by Google App Engine
This is Rietveld 408576698